# Note to packagers/builders:
#
# If you wish to build the LookAhead or Beta variant of this package, make sure
# that you are setting --with=nbeta or --with=nlookahead on your mock
# command. See the README for more information.

%bcond_with nbeta
%bcond_with nlookahead
%bcond_with noverride

%define debug_package %{nil}

# Product information
%define product_family Navix
%define variant_titlecase Server
%define variant_lowercase server

# Distribution Name and Version
%define distro_name  Navix
%define distro       %{distro_name}
%define distro_code  Jeongja
%define major        9
%define minor        5
%define navix_rel    0.2
%define rpm_license  GPLv2
%define dist         .el%{major}
%define home_url     https://navix.navercorp.com/
%define bug_url      https://github.com/NaverCloudPlatform/Navix
%define debug_url    https://navix.navercorp.com/
%define dist_vendor  Naver Cloud Corp.

%define contentdir   pub/navix
%define sigcontent   pub/sig
%define rlosid       navix

%define os_bug_name  Navix-%{major}

################################################################################
# Navix LookAhead Section
%if %{with nlookahead}
%define minor        1
%define contentdir   pub/navix-lh
%define ntype        -lookahead
%define nstatement   LookAhead
%endif
################################################################################

################################################################################
# Navix Beta Section
%if %{with nbeta}
%define contentdir   pub/navix-beta
%define ntype        -beta
%define nstatement   Beta
%endif
################################################################################

################################################################################
# Navix Override Section
%if %{with noverride}
%define dist         .el%{major}.override
%define rlosid       rhel
%endif
################################################################################

%define base_release_version %{major}
%define dist_release_version %{major}
%define full_release_version %{major}.%{minor}

%ifarch ppc64le
%define tuned_profile :server
%endif

# Avoids a weird anaconda problem
%global __requires_exclude_from %{_libexecdir}

# conditional section for future use

Name:           navix-release%{?ntype}
Version:        %{full_release_version}
Release:        %{navix_rel}%{dist}
Summary:        %{distro_name} release files
Group:          System Environment/Base
License:        %{rpm_license}
URL:            https://navix.navercorp.com/
BuildArch:      noarch

# What do we provide? Some of these needs are a necesity (think comps and
# groups) and things like EPEL need it.
Provides:       navix-release = %{version}-%{release}
Provides:       navix-release(upstream) = %{full_release_version}
Provides:       redhat-release = %{version}-%{release}
Provides:       system-release = %{version}-%{release}
Provides:       system-release(releasever) = %{major}
Provides:       centos-release = %{version}-%{release}
Provides:       centos-release(upstream) = %{full_release_version}

## Required by libdnf
Provides:       base-module(platform:el%{major})

## This makes lorax/pungi/anaconda happy
Provides:       navix-release-eula  = %{version}-%{release}
Provides:       redhat-release-eula = %{version}-%{release}
Provides:       centos-release-eula = %{version}-%{release}

# What are our requirements?
Requires:       navix-repos(%{major})

# GPG Keys (100-199)
Source101:      RPM-GPG-KEY-navixofficial
Source102:      RPM-GPG-KEY-navixtesting

# Release Sources (200-499)
Source200:      EULA
Source201:      GPL
Source202:      Contributors

# !! Stable !!
Source300:      85-display-manager.preset
Source301:      90-default.preset
Source302:      90-default-user.preset
Source303:      99-default-disable.preset
Source304:      50-redhat.conf

# !! LookAhead !!
Source400:      85-display-manager.preset.lh
Source401:      90-default.preset.lh
Source402:      90-default-user.preset.lh
Source403:      99-default-disable.preset.lh
Source404:      50-redhat.conf.lh

# Repo Sources (1200-1299)
Source1200:     navix.repo

# Add ons (1300-1399)
Source1300:     navix.1.gz

# navix secureboot certs placeholder (1400-1499)
Source1400:     navix-root-ca.der
Source1401:     navixdup1.x509
Source1402:     navixkpatch1.x509

# x86_64
Source1411:     navix-fwupd.cer
Source1412:     navix-grub2.cer
Source1413:     navix-kernel.cer
Source1414:     navix-shim.cer
Source1415:     navix-uki-virt.cer
# x86_64 in der
Source1416:     navix-fwupd.der
Source1417:     navix-grub2.der
Source1418:     navix-kernel.der
Source1419:     navix-shim.der
Source1420:     navix-uki-virt.der


%description
%{distro_name} release files.

%package     -n navix-repos%{?ntype}
Summary:        %{distro_name} Package Repositories
Provides:       system-repos = %{version}-%{release}
Provides:       navix-repos(%{major}) = %{full_release_version}
Requires:       system-release = %{version}-%{release}
Requires:       navix-gpg-keys%{?ntype}
Conflicts:      %{name} < 9.0

%description -n navix-repos%{?ntype}
%{distro_name} package repository files for yum/dnf

%package     -n navix-gpg-keys%{?ntype}
Summary:        Navix RPM GPG Keys
Conflicts:      %{name} < 9.0

%description -n navix-gpg-keys%{?ntype}
This package provides the RPM signature keys for Navix.

%package     -n navix-sb-certs%{?ntype}
Summary:        %{distro_name} public secureboot certificates
Group:          System Environment/Base
Provides:       system-sb-certs = %{version}-%{release}
Provides:       redhat-sb-certs = %{version}-%{release}
Provides:       centos-sb-certs = %{version}-%{release}

%description -n navix-sb-certs%{?ntype}
This package contains the %{distro_name} secureboot public certificates.


%prep
%if %{with nlookahead} && %{with nbeta}
echo "!! WARNING !!"
echo "Both LookAhead and Beta were enabled. This is not supported."
echo "As a result: BUILD FAILED."
exit 1
%endif
echo Good.

%build
echo Good.

%install
# docs dir for license and contributors
mkdir ./docs
cp %{SOURCE201} %{SOURCE202} ./docs

################################################################################
# system-release data
install -d -m 0755 %{buildroot}%{_sysconfdir}
echo "%{distro_name} release %{full_release_version}%{?nstatement: %{nstatement}} (%{distro_code})" > %{buildroot}%{_sysconfdir}/navix-release
echo "Derived from Red Hat Enterprise Linux %{full_release_version}" > %{buildroot}%{_sysconfdir}/navix-release-upstream
ln -s navix-release %{buildroot}%{_sysconfdir}/system-release
ln -s navix-release %{buildroot}%{_sysconfdir}/redhat-release
mkdir -p %{buildroot}%{_mandir}/man1
install -p -m 0644 %{SOURCE1300} %{buildroot}%{_mandir}/man1/

# Create the os-release file
install -d -m 0755 %{buildroot}%{_prefix}/lib
cat > %{buildroot}%{_prefix}/lib/os-release << EOF
NAME="%{distro_name}"
VERSION="%{full_release_version} (%{distro_code})"
ID="%{rlosid}"
ID_LIKE="rhel centos fedora"
VERSION_ID="%{full_release_version}"
PLATFORM_ID="platform:el%{major}"
PRETTY_NAME="%{distro_name} %{full_release_version}%{?nstatement: %{nstatement}} (%{distro_code})"
ANSI_COLOR="0;36"
CPE_NAME="cpe:/o:navix:navix:%{major}::baseos"
HOME_URL="%{home_url}"
BUG_REPORT_URL="%{bug_url}"
NAVIX_SUPPORT_PRODUCT="%{os_bug_name}"
NAVIX_SUPPORT_PRODUCT_VERSION="%{full_release_version}%{?nstatement:-%{nstatement}}"
REDHAT_SUPPORT_PRODUCT="%{distro_name}"
REDHAT_SUPPORT_PRODUCT_VERSION="%{full_release_version}%{?nstatement: %{nstatement}}"
EOF

# Create the symlink for /etc/os-release
ln -s ../usr/lib/os-release %{buildroot}%{_sysconfdir}/os-release

# write cpe to /etc/system/release-cpe
echo "cpe:/o:navix:navix:%{major}::baseos" > %{buildroot}%{_sysconfdir}/system-release-cpe

# create /etc/issue and /etc/issue.net, /etc/issue.d
echo '\S' > %{buildroot}%{_sysconfdir}/issue
echo 'Kernel \r on an \m' >> %{buildroot}%{_sysconfdir}/issue
cp %{buildroot}%{_sysconfdir}/issue{,.net}
echo >> %{buildroot}%{_sysconfdir}/issue
mkdir -p %{buildroot}%{_sysconfdir}/issue.d

# set up the dist tag macros
mkdir -p %{buildroot}%{_rpmmacrodir}
cat > %{buildroot}%{_rpmmacrodir}/macros.dist << EOF
# dist macros.

%%__bootstrap ~bootstrap
%%navix_ver %{major}
%%navix %{major}
%%centos_ver %{major}
%%centos %{major}
%%rhel %{major}
%%dist %{dist}	
%%el%{major} 1

%%dist_vendor         %{dist_vendor}
%%dist_name           %{distro}
%%dist_home_url       %{home_url}
%%dist_bug_report_url %{bug_url}
%%dist_debuginfod_url %{debug_url}
EOF

# Data directory
install -d -m 0755 %{buildroot}%{_datadir}/navix-release
ln -s navix-release %{buildroot}%{_datadir}/redhat-release
install -p -m 0644 %{SOURCE200} %{buildroot}%{_datadir}/navix-release/

mkdir -p -m 755 %{buildroot}/%{_docdir}/navix-release
ln -s navix-release %{buildroot}/%{_docdir}/redhat-release
install -m 644 %{SOURCE201} %{buildroot}/%{_docdir}/navix-release

# end system-release data
################################################################################

################################################################################
# systemd section
install -d -m 0755 %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -d -m 0755 %{buildroot}%{_prefix}/lib/systemd/user-preset/

install -m 0644 %{SOURCE300} %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE301} %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE302} %{buildroot}/%{_prefix}/lib/systemd/user-preset/

# same behavior for both presets
install -m 0644 %{SOURCE303} %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE303} %{buildroot}/%{_prefix}/lib/systemd/user-preset/

# sysctl presets
install -d -m 0755 %{buildroot}%{_prefix}/lib/sysctl.d/
install -m 0644 %{SOURCE304} %{buildroot}/%{_prefix}/lib/sysctl.d/
# systemd section
################################################################################

################################################################################
# start secureboot section
install -d -m 0755 %{buildroot}%{_sysconfdir}/pki/sb-certs/
install -d -m 0755 %{buildroot}%{_datadir}/pki/sb-certs/

# Backported certs for now
install -m 0644 %{SOURCE1400} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1401} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1402} %{buildroot}%{_datadir}/pki/sb-certs/
# x86_64 (cer)
install -m 0644 %{SOURCE1411} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1412} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1413} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1414} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1415} %{buildroot}%{_datadir}/pki/sb-certs/
# x86_64 (der)
install -m 0644 %{SOURCE1416} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1417} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1418} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1419} %{buildroot}%{_datadir}/pki/sb-certs/
install -m 0644 %{SOURCE1420} %{buildroot}%{_datadir}/pki/sb-certs/

# Placeholders
# x86_64
ln -sr %{buildroot}%{_datadir}/pki/sb-certs/navix-root-ca.der %{buildroot}%{_datadir}/pki/sb-certs/secureboot-ca-x86_64.cer
ln -sr %{buildroot}%{_datadir}/pki/sb-certs/navix-kernel.cer %{buildroot}%{_datadir}/pki/sb-certs/secureboot-kernel-x86_64.cer
ln -sr %{buildroot}%{_datadir}/pki/sb-certs/navix-grub2.cer %{buildroot}%{_datadir}/pki/sb-certs/secureboot-grub2-x86_64.cer
ln -sr %{buildroot}%{_datadir}/pki/sb-certs/navix-fwupd.cer %{buildroot}%{_datadir}/pki/sb-certs/secureboot-fwupd-x86_64.cer
ln -sr %{buildroot}%{_datadir}/pki/sb-certs/navix-shim.cer %{buildroot}%{_datadir}/pki/sb-certs/secureboot-shim-x86_64.cer
ln -sr %{buildroot}%{_datadir}/pki/sb-certs/navix-uki-virt.cer %{buildroot}%{_datadir}/pki/sb-certs/secureboot-uki-virt-x86_64.cer

# symlinks for everybody
for x in $(ls %{buildroot}%{_datadir}/pki/sb-certs); do
  ln -sr %{buildroot}%{_datadir}/pki/sb-certs/${x} %{buildroot}%{_sysconfdir}/pki/sb-certs/${x}
done

# end secureboot section
################################################################################

################################################################################
# dnf repo section
install -d -m 0755 %{buildroot}%{_sysconfdir}/yum.repos.d
install -p -m 0644 %{SOURCE1200} %{buildroot}%{_sysconfdir}/yum.repos.d/

# dnf stuff
install -d -m 0755 %{buildroot}%{_sysconfdir}/dnf/vars
echo "%{contentdir}" > %{buildroot}%{_sysconfdir}/dnf/vars/contentdir
echo "%{sigcontent}" > %{buildroot}%{_sysconfdir}/dnf/vars/sigcontentdir
echo "%{?ntype}" > %{buildroot}%{_sysconfdir}/dnf/vars/ntype
echo "%{major}-stream" > %{buildroot}%{_sysconfdir}/dnf/vars/stream

# Copy out GPG keys
install -d -m 0755 %{buildroot}%{_sysconfdir}/pki/rpm-gpg
install -p -m 0644 %{SOURCE101} %{buildroot}%{_sysconfdir}/pki/rpm-gpg/
install -p -m 0644 %{SOURCE102} %{buildroot}%{_sysconfdir}/pki/rpm-gpg/
# end dnf repo section
################################################################################

################################################################################
# lookahead overrides
%if %{with nlookahead}
install -m 0644 %{SOURCE400} %{buildroot}/%{_prefix}/lib/systemd/system-preset/85-display-manager.preset
install -m 0644 %{SOURCE401} %{buildroot}/%{_prefix}/lib/systemd/system-preset/90-default.preset
install -m 0644 %{SOURCE402} %{buildroot}/%{_prefix}/lib/systemd/user-preset/90-default-user.preset

install -m 0644 %{SOURCE403} %{buildroot}/%{_prefix}/lib/systemd/system-preset/99-default-disable.preset
install -m 0644 %{SOURCE403} %{buildroot}/%{_prefix}/lib/systemd/user-preset/99-default-disable.preset
install -m 0644 %{SOURCE404} %{buildroot}/%{_prefix}/lib/sysctl.d/50-redhat.conf
%endif
# lookahead replacements
################################################################################

%files
%doc docs/Contributors
%dir %{_sysconfdir}/yum.repos.d
%{_sysconfdir}/redhat-release
%{_sysconfdir}/system-release
%{_sysconfdir}/navix-release
%{_sysconfdir}/navix-release-upstream
%config(noreplace) %{_sysconfdir}/os-release
%config %{_sysconfdir}/system-release-cpe
%config(noreplace) %{_sysconfdir}/issue
%config(noreplace) %{_sysconfdir}/issue.net
%dir %{_sysconfdir}/issue.d
%{_rpmmacrodir}/macros.dist
%{_docdir}/redhat-release
%{_docdir}/navix-release
%{_datadir}/redhat-release
%{_datadir}/navix-release
%{_prefix}/lib/os-release
%{_prefix}/lib/systemd/system-preset/*
%{_prefix}/lib/systemd/user-preset/*
%{_prefix}/lib/sysctl.d/50-redhat.conf
%{_mandir}/man1/navix.1.gz

%files -n navix-repos%{?ntype}
%config(noreplace) %{_sysconfdir}/yum.repos.d/navix.repo
%config(noreplace) %{_sysconfdir}/dnf/vars/contentdir
%config(noreplace) %{_sysconfdir}/dnf/vars/sigcontentdir
%config(noreplace) %{_sysconfdir}/dnf/vars/ntype
%config(noreplace) %{_sysconfdir}/dnf/vars/stream

%files -n navix-gpg-keys%{?ntype}
%{_sysconfdir}/pki/rpm-gpg/

%files -n navix-sb-certs%{?ntype}
# care: resetting symlinks is intended
%dir %{_sysconfdir}/pki/sb-certs
%dir %{_datadir}/pki/sb-certs
%{_sysconfdir}/pki/sb-certs/*
%{_datadir}/pki/sb-certs/*

%changelog
* Thu Dec 12 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.5-0.2
- add source repo

* Thu Oct 31 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.5-0.1
- bump release

* Thu Oct 10 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.4-0.5
- edit repo, bugfix URLs

* Wed Sep 11 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.4-0.4
- fix URLs for public release

* Wed May 29 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.4-0.3
- update sb certificates
- add certs for kernel

* Wed May 29 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.4-0.2
- add new GPL file
- remove license field for the navix-repos subpackage

* Tue May 28 2024 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.4-0.1
- bump version
- add x86_64 secure boot certificates

* Fri Nov 24 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.3-1.0
- Navix release 9.3
- edit dir for macros.dist

* Mon Jun 26 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.2-3.3
- edit repo name ($releasever)

* Mon Jun 26 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.2-3.2
- edit navix.repo ($releasever), rename gpg key

* Thu Jun 15 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.2-3.1
- enable repos 

* Tue Jun 13 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.2-3.0
- add rpm-gpg-key, edit repo url

* Fri Jun 09 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.2-2.0
- add updates repo

* Thu Apr 06 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.2-1.0
- Navix 9.2 (Jeongja)

* Tue Feb 21 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.1-1.0
- Navix 9.1 (Jeongja)

* Wed Jan 18 2023 Songhee Yeon <song-hee.yeon@navercorp.com> - 9.0-1.0
- Init for Navix 9 (Jeongja)
